summaryrefslogtreecommitdiffstats
path: root/board/keymile/km_arm/km_arm.c
diff options
context:
space:
mode:
authorHolger Brunck <holger.brunck@keymile.com>2012-07-05 05:37:46 +0000
committerAlbert ARIBAUD <albert.u.boot@aribaud.net>2012-07-07 14:07:36 +0200
commit8170aefc84b04af1e5bd217b04aef81a047f8d28 (patch)
tree8d6519d049658c4bd45108269717995eef408c0f /board/keymile/km_arm/km_arm.c
parentfa042186b932e9b9ee9a2fd8a04a3acf7c70d224 (diff)
downloadblackbird-obmc-uboot-8170aefc84b04af1e5bd217b04aef81a047f8d28.tar.gz
blackbird-obmc-uboot-8170aefc84b04af1e5bd217b04aef81a047f8d28.zip
arm/km: add kmnusa board support
This board is similar to portl2, but it has the u-boot environment in a SPI NOR flash and not in an i2c eeprom like portl2 have. Some other details: - IVM EEPROM is at adress: pca9547:70:9 - PCI is enabled - PIGGY4 is connected via MV88E6352 simple switch. There is no phy between the simple switch and the kirkwood. Signed-off-by: Holger Brunck <holger.brunck@keymile.com> Signed-off-by: Valentin Longchamp <valentin.longchamp@keymile.com> cc: Gerlando Falauto <gerlando.falauto@keymile.com> cc: Prafulla Wadaskar <prafulla@marvell.com>
Diffstat (limited to 'board/keymile/km_arm/km_arm.c')
-rw-r--r--board/keymile/km_arm/km_arm.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/board/keymile/km_arm/km_arm.c b/board/keymile/km_arm/km_arm.c
index cb3402b8f9..e77c5ad96d 100644
--- a/board/keymile/km_arm/km_arm.c
+++ b/board/keymile/km_arm/km_arm.c
@@ -134,10 +134,11 @@ int startup_allowed(void)
}
#endif
-#if (defined(CONFIG_MGCOGE3UN)|defined(CONFIG_PORTL2))
+#if (defined(CONFIG_MGCOGE3UN)|defined(CONFIG_PORTL2)| \
+ defined(CONFIG_KM_PIGGY4_88E6352))
/*
* These two boards have always ethernet present. Its connected to the mv
* switch.
*/
int ethernet_present(void)
{
@@ -134,10 +134,11 @@ int startup_allowed(void)
/*
- * These two boards have always ethernet present. Its connected to the mv
- * switch.
+ * All boards with PIGGY4 connected via a simple switch have ethernet always
+ * present.
*/
int ethernet_present(void)
OpenPOWER on IntegriCloud